# encoding: utf-8

# Copyright (c) 2020 Micro Focus or one of its affiliates.
# File:	clients/nss_proposal.ycp
# Package:	Configuration of nss
# Summary:	Proposal function dispatcher.
# Authors:	Reed Haslam <Reed_Haslam@Novell.com>
#
# $Id: nss_proposal.ycp,v 1.1.2.6 2005/02/10 21:20:33 sbunch Exp $
#
# Proposal function dispatcher for nss configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NssProposalClient < Client
    def main

      textdomain "novell-nss"

      Yast.import "Nss"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellUtils"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Nss proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if NovellUtils.EdirAskUserFlag("nss") # If edir changed, then we need to recompute the defaults.
          @force_reset = true
          Builtins.y2milestone(
            "novell-nss.MakeProposal:force_reset set to true due to ask user flag."
          )
        end

        if @force_reset || !Nss.proposal_valid
          Nss.proposal_valid = true
          @progress_orig = Progress.set(false)
          Nss.Read
          Progress.set(@progress_orig)
        end
        @sum = Nss.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("nss", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }
        #if the user needs to be warned, warn them and block on page
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == "" &&
            Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
            Ops.get_string(Nss.Settings, "CONFIG_NSS_NSSADMIN_DN", "") == ""
          Ops.set(@ret, "errors", true)
        end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("Nss proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "nss--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "nss", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "nss--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "nss", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = Nss.Export
          @seq = Convert.to_symbol(WFM.CallFunction("nss", [path(".propose")]))
          Nss.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-nss") # FIXME: is this needed anymore?
        @isSelected = @isSelected && NovellAddonInstall.IsProductSelected("nss")
        Builtins.y2milestone("Proposal:IsSelected:novell-nss: %1", @isSelected)
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Nss in proposals
            "rich_text_title" => _(
              "OES Storage Services (NSS)"
            ),
            # Menu title for Nss in proposals
            "menu_title"      => _(
              "OES S&torage Services"
            ),
            "id"              => "nss"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        Nss.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Nss proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NssProposalClient.new.main
