# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------

# File:	include/novell-nss/dialogs.ycp
# Package:	Configuration of nss
# Summary:	Dialogs definitions
# Authors:	Reed Haslam <Reed_Haslam@Novell.com>
#
# $Id: dialogs.ycp,v 1.1.2.14 2005/09/28 21:01:38 mclark Exp $
module Yast
  module NovellNssDialogsInclude
    def initialize_novell_nss_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-nss"

      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "Edirectory"
      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "NovellLdapBrowser"

      Yast.include include_target, "novell-nss/helps.rb"
      Yast.include include_target, "novell-nss/complex.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if Nss.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true
        end # if this value is set at all, then it is the eDir admin (in spite of xad name)
      end
      Builtins.y2milestone("Nss:use xad:%1", useXad)

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end
      Builtins.y2milestone(
        "Nss.PromptIfNeededForEdirAdminPassword:useXad %1",
        useXad
      )
      useXad
    end


    def Admin_Dialog
      # NSS configure2 dialog caption
      caption = _("NSS Unique Admin Object")

      gbl_ldap_user = ""

      adminName = Ops.get_string(Nss.Settings, "CONFIG_NSS_NSSADMIN_DN", "")
      ldap_server = Ops.get_string(Nss.Settings, "CONFIG_NSS_LDAP_SERVER", "")
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )

      #  configure1 dialog contents

      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("Directory Server Address"),
        ldap_server,
        true,
        :combo
      )
      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      # We need to know this later during Write() if the user changed the value.
      orgAdminName = NovellUtils.Nds2Ldap(adminName)

      contents = HVSquash(
        VBox(
          ldap_widget,
          VSpacing(1),
          Left(Label(_("Unique object name for NSS admin of this"))),
          MinWidth(
            50,
            HBox(
              TextEntry(
                Id(:adminName),
                Opt(:notify),
                _("ser&ver: (e.g. cn=HOSTNAMEadmin,o=microfocus)    "),
                adminName
              ),
              VBox(Label(""), PushButton(Id(:browse), _("Br&owse")))
            )
          ),
          Left(Label(_("Novell Identity Translator (NIT) Configuration")))
        )
      )
      contents = HVSquash(VBox(contents, Nss.NitRangeDialog))

      helps = Ops.add(
        Ops.add(
          Ops.get_string(server_list_widget, "helps", ""),
          Ops.get_string(@HELPS, "c2", "")
        ),
        Ops.get_string(@HELPS, "c3", "")
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse), :Enabled, true)
      end

      PromptIfNeededForEdirAdminPassword()

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          ldap_server = Convert.to_string(
            UI.QueryWidget(Id(:server_select), :Value)
          )
          adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
          if Builtins.substring(adminName, 0, 2) != "cn"
            Popup.Message("Select user object.")
            next
          end
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end
          next if !NovellValidators.ValidateFDN(adminName, false)
          Ops.set(Nss.Settings, "CONFIG_NSS_LDAP_SERVER", ldap_server)
          if orgAdminName != NovellUtils.Nds2Ldap(adminName)
            Nss.userChangedData = true
          end
          Ops.set(Nss.Settings, "CONFIG_NSS_NSSADMIN_DN", adminName)
          next if Nss.NitRangeNextButton == :continue
          break
        elsif ret == :adminName
          gbl_ldap_user = NovellUtils.Nds2Ldap(
            Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
          )
        elsif ret == :browse
          primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
          ldap_server2 = Ops.get_string(
            primary_server,
            "CONFIG_LDAP_SERVER_IP",
            ""
          )
          ldap_sport = Ops.get_integer(
            primary_server,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Nss.xadMode
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "NSS:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("NSS:admin:%1", adminDn)
          gbl_ldap_user = "" if Builtins.substring(gbl_ldap_user, 0, 3) != "cn="

          adminName2 = NovellLdapBrowser.LdapBrowser(
            ldap_server2,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )

          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              adminName2
            )
          )
          if adminName2 != nil && adminName2 != ""
            adminName2 = NovellUtils.Nds2Ldap(adminName2)

            if gbl_ldap_user != nil && gbl_ldap_user != ""
              gbl_ldap_user = NovellUtils.Nds2Ldap(gbl_ldap_user)
              adminName2 = Ops.add(Ops.add(gbl_ldap_user, ","), adminName2)
            else
              adminName2 = Ops.add(
                Ops.add(Ops.add("cn=", NovellUtils.GetHostname), "admin,"),
                adminName2
              )
            end

            UI.ChangeWidget(Id(:adminName), :Value, adminName2)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end
  end
end
