# encoding: utf-8

# File:	include/novell-nss/wizards.ycp
# Package:	Configuration of Nss
# Summary:	Wizards definitions
# Authors:	Reed Haslam <Reed_Haslam@Novell.com>
#
# $Id: wizards.ycp,v 1.1.2.2 2004/12/03 00:04:44 sbunch Exp $
module Yast
  module NovellNssWizardsInclude
    def initialize_novell_nss_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-nss"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-nss/dialogs.rb"
    end

    # Main workflow of the Nss configuration
    # @return sequence result
    def MainSequence
      aliases = { "admin" => lambda { Admin_Dialog() } }

      sequence = {
        "ws_start" => "admin",
        "admin"    => { :abort => :abort, :next => :next }
      }

      Sequencer.Run(aliases, sequence)
    end

    # Whole configuration of Nss
    # @return sequence result
    def NssSequence
      # Add a configuration of Nss
      # @return sequence result



      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("nss")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of Nss but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def NssAutoSequence
      # Initialization dialog caption
      caption = _("Nss Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("nss")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
